@@ -19,7 +19,7 @@
 //KDE includes
 #include <kfinddialog.h>
 #include <kfind.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 
 //Project includes
 #include "logManager.h"
@@ -36,7 +36,7 @@ class KSystemLog;
 class FindManager : public TQObject {
 
 	Q_OBJECT
-  TQ_OBJECT
+  
 	
 	public:
 		/**
