@@ -32,42 +32,42 @@
 
 
 //KDE includes
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
-#include <kwin.h>
+#include <twin.h>
 #include <kprinter.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 
 #include <kiconloader.h>
 
 #include <kservice.h>
 
-#include <kmenubar.h>
+#include <tdemenubar.h>
 #include <kstatusbar.h>
 #include <kkeydialog.h>
 
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 
-#include <kaccel.h>
+#include <tdeaccel.h>
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 //For compatibility with old versions of KDE
-#include <kdeversion.h>
+#include <tdeversion.h>
 
 #include <dcopclient.h>
 
 #include <kurl.h>
 #include <kurldrag.h>
 #include <kurlrequesterdlg.h>
-#include <ktoolbarbutton.h>
+#include <tdetoolbarbutton.h>
 #include <kedittoolbar.h>
 #include <kdebug.h>
 #include <kiconloader.h>
 
-#include <kstdaccel.h>
-#include <kaction.h>
+#include <tdestdaccel.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
 
 //Project includes
@@ -86,7 +86,7 @@
 #include "readerFactory.h"
 
 KSystemLog::KSystemLog() :
-	KMainWindow(0, "ksystemlog"),
+	TDEMainWindow(0, "ksystemlog"),
 	printer(NULL),
 	detailDialog(NULL),
 	loadingDialog(NULL),
@@ -117,7 +117,7 @@ KSystemLog::KSystemLog() :
 	//Setup the main tab bar
 	setupTabBar();
 		
-	//TabBar widget becomes the central place of the KMainWindow
+	//TabBar widget becomes the central place of the TDEMainWindow
 	setCentralWidget(tabs);
 
 	//Setup the Progress Bar Dialog
@@ -248,7 +248,7 @@ void KSystemLog::currentTabChanged(TQWidget* /*widget*/) {
 	
 	//Modify the menu button to help the user know what is the currently log mode
 	//setModeToAction(currentManager->getLogMode(), true);
-	KToggleAction* action=getCorrespondingLogAction(currentManager->getLogMode());
+	TDEToggleAction* action=getCorrespondingLogAction(currentManager->getLogMode());
 	if (action!=NULL)
 		action->setChecked(true);
 	
@@ -295,22 +295,22 @@ void KSystemLog::setupActions() {
 	copyAction->setWhatsThis(i18n("Copies the selection to the clipboard. This action is useful if you want to paste the selection in a chat or an email."));	
 	copyAction->setEnabled(false);
 	
-	expandAllAction=new KAction(i18n("Ex&pand All"), NULL, CTRL+Key_X, TQT_TQOBJECT(this), NULL, actionCollection(), "expand_all" );
+	expandAllAction=new TDEAction(i18n("Ex&pand All"), NULL, CTRL+Key_X, TQT_TQOBJECT(this), NULL, actionCollection(), "expand_all" );
 	expandAllAction->setToolTip(i18n("Expand all categories"));
 	expandAllAction->setWhatsThis(i18n("<qt>This action opens all main categories. This is enabled only if an option has been selected in the <b>Group By</b> menu.</qt>"));
 	expandAllAction->setEnabled(false);
 	
-	collapseAllAction=new KAction(i18n("Col&lapse All"), NULL, CTRL+Key_L, TQT_TQOBJECT(this), NULL, actionCollection(), "collapse_all" );
+	collapseAllAction=new TDEAction(i18n("Col&lapse All"), NULL, CTRL+Key_L, TQT_TQOBJECT(this), NULL, actionCollection(), "collapse_all" );
 	collapseAllAction->setToolTip(i18n("Collapse all categories"));
 	collapseAllAction->setWhatsThis(i18n("<qt>This action closes all main categories. This is enabled only if an option has been selected in the <b>Group By</b> menu.</qt>"));
 	collapseAllAction->setEnabled(false);
 	
-	sendMailAction=new KAction(i18n("&Email Selection..."), "mail_generic", CTRL+Key_M, TQT_TQOBJECT(this), NULL, actionCollection(), "send_mail" );
+	sendMailAction=new TDEAction(i18n("&Email Selection..."), "mail_generic", CTRL+Key_M, TQT_TQOBJECT(this), NULL, actionCollection(), "send_mail" );
 	sendMailAction->setToolTip(i18n("Send the selection by mail"));
 	sendMailAction->setWhatsThis(i18n("Sends the selection by mail. Simply select the important lines and click on this menu entry to send the selection to a friend or a mailing list."));	
 	sendMailAction->setEnabled(false);
 	
-	logMessageAction=new KAction(i18n("&Send Message..."), "filenew", CTRL+Key_L, TQT_TQOBJECT(this), TQT_SLOT(slotLogMessage()), actionCollection(), "log_message" );
+	logMessageAction=new TDEAction(i18n("&Send Message..."), "document-new", CTRL+Key_L, TQT_TQOBJECT(this), TQT_SLOT(slotLogMessage()), actionCollection(), "log_message" );
 	logMessageAction->setToolTip(i18n("Send a message to the log system"));
 	logMessageAction->setWhatsThis(i18n("This action will open a dialog which lets you send a message to the log system."));
 	
@@ -322,8 +322,8 @@ void KSystemLog::setupActions() {
 	KStdAction::findNext(findManager, TQT_SLOT(slotFindNext()), actionCollection(), "find_next");
 
 	//TODO Find a solution to display at the right place this action (see Akregator interface)
-	filterBarAction=new KToggleAction(i18n("Show &Filter Bar"), TQString(), 0, TQT_TQOBJECT(this), TQT_SLOT(slotToggleFilterBar()), actionCollection(), "toggle_filter_bar");
-#if defined(KDE_MAKE_VERSION) && KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
+	filterBarAction=new TDEToggleAction(i18n("Show &Filter Bar"), TQString(), 0, TQT_TQOBJECT(this), TQT_SLOT(slotToggleFilterBar()), actionCollection(), "toggle_filter_bar");
+#if defined(TDE_MAKE_VERSION) && TDE_VERSION >= TDE_MAKE_VERSION(3,3,0)
 	filterBarAction->setEnabled(true);
 #else
 	filterBarAction->setEnabled(false);
@@ -331,53 +331,53 @@ void KSystemLog::setupActions() {
 
 	KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotOptions()), actionCollection());
 	
-	newTabAction=new KAction(i18n("&New Tab"), "tab_new", CTRL+Key_T, TQT_TQOBJECT(this), TQT_SLOT(newTab()), actionCollection(), "new_tab" );
+	newTabAction=new TDEAction(i18n("&New Tab"), "tab_new", CTRL+Key_T, TQT_TQOBJECT(this), TQT_SLOT(newTab()), actionCollection(), "new_tab" );
 	newTabAction->setToolTip(i18n("Create a new tab"));
 	newTabAction->setWhatsThis(i18n("Creates a new tab which can display another log."));
 	
-	closeTabAction=new KAction(i18n("&Close Tab"), "tab_remove", CTRL+Key_W, TQT_TQOBJECT(this), TQT_SLOT(closeTab()), actionCollection(), "close_tab" );
+	closeTabAction=new TDEAction(i18n("&Close Tab"), "tab_remove", CTRL+Key_W, TQT_TQOBJECT(this), TQT_SLOT(closeTab()), actionCollection(), "close_tab" );
 	closeTabAction->setToolTip(i18n("Close the current tab"));
 	closeTabAction->setWhatsThis(i18n("Closes the current tab."));
 	
-	duplicateTabAction=new KAction(i18n("&Duplicate Tab"), "tab_duplicate", SHIFT+CTRL+Key_N, TQT_TQOBJECT(this), TQT_SLOT(duplicateTab()), actionCollection(), "duplicate_tab" );
+	duplicateTabAction=new TDEAction(i18n("&Duplicate Tab"), "tab_duplicate", SHIFT+CTRL+Key_N, TQT_TQOBJECT(this), TQT_SLOT(duplicateTab()), actionCollection(), "duplicate_tab" );
 	duplicateTabAction->setToolTip(i18n("Duplicate the current tab"));
 	duplicateTabAction->setWhatsThis(i18n("Duplicates the current tab."));
 	
-	moveTabLeftAction=new KAction(i18n("Move Tab &Left"), "1leftarrow", SHIFT+CTRL+Key_Left, TQT_TQOBJECT(this), TQT_SLOT(moveTabLeft()), actionCollection(), "move_tab_left" );
+	moveTabLeftAction=new TDEAction(i18n("Move Tab &Left"), "1leftarrow", SHIFT+CTRL+Key_Left, TQT_TQOBJECT(this), TQT_SLOT(moveTabLeft()), actionCollection(), "move_tab_left" );
 	moveTabLeftAction->setToolTip(i18n("Move the current tab to the left"));
 	moveTabLeftAction->setWhatsThis(i18n("Moves the current tab to the left."));
 	
-	moveTabRightAction=new KAction(i18n("Move Tab &Right"), "1rightarrow", SHIFT+CTRL+Key_Right, TQT_TQOBJECT(this), TQT_SLOT(moveTabRight()), actionCollection(), "move_tab_right" );
+	moveTabRightAction=new TDEAction(i18n("Move Tab &Right"), "1rightarrow", SHIFT+CTRL+Key_Right, TQT_TQOBJECT(this), TQT_SLOT(moveTabRight()), actionCollection(), "move_tab_right" );
 	moveTabRightAction->setToolTip(i18n("Move the current tab to the right"));
 	moveTabRightAction->setWhatsThis(i18n("Moves the current tab to the right."));
 	
 	
-	reloadAction=new KAction(i18n("&Reload"), "reload", Key_F5, TQT_TQOBJECT(this), TQT_SLOT(reloadCurrent()), actionCollection(), "reload" );
+	reloadAction=new TDEAction(i18n("&Reload"), "reload", Key_F5, TQT_TQOBJECT(this), TQT_SLOT(reloadCurrent()), actionCollection(), "reload" );
 	reloadAction->setToolTip(i18n("Reload the current log"));
 	reloadAction->setWhatsThis(i18n("Reloads the current log, if you want to be sure that the view is correctly updated."));
 	
-	resumeParsingAction=new KAction(i18n("Resu&me Parsing"), "player_play", CTRL+Key_M, TQT_TQOBJECT(this), TQT_SLOT(resumeParsing()), actionCollection(), "resume_parsing");
+	resumeParsingAction=new TDEAction(i18n("Resu&me Parsing"), "media-playback-start", CTRL+Key_M, TQT_TQOBJECT(this), TQT_SLOT(resumeParsing()), actionCollection(), "resume_parsing");
 	resumeParsingAction->setToolTip(i18n("Resume the watching of the current log"));
 	resumeParsingAction->setWhatsThis(i18n("Resumes the watching of the current log. This action is only available when the user has already paused the reading."));
 	resumeParsingAction->setEnabled(true);
 	
-	pauseParsingAction=new KAction(i18n("S&top Parsing"), "player_stop", CTRL+Key_P, TQT_TQOBJECT(this), TQT_SLOT(pauseParsing()), actionCollection(), "pause_parsing");
+	pauseParsingAction=new TDEAction(i18n("S&top Parsing"), "media-playback-stop", CTRL+Key_P, TQT_TQOBJECT(this), TQT_SLOT(pauseParsing()), actionCollection(), "pause_parsing");
 	pauseParsingAction->setToolTip(i18n("Pause the watching of the current log"));
 	pauseParsingAction->setWhatsThis(i18n("Pauses the watching of the current log. This action is particularly useful when the system is writing too many lines to log files, causing KSystemLog to reload too frequently."));
 
-	detailAction=new KAction(i18n("&Details"), "viewmag", ALT+Key_Return, TQT_TQOBJECT(this), TQT_SLOT(slotDetails()), actionCollection(), "details");
+	detailAction=new TDEAction(i18n("&Details"), "viewmag", ALT+Key_Return, TQT_TQOBJECT(this), TQT_SLOT(slotDetails()), actionCollection(), "details");
 	detailAction->setToolTip(i18n("Display details on the currently selected line"));
 	detailAction->setWhatsThis(i18n("Displays a dialog box which contains details on the currently selected line. You are able to navigate through the logs from this dialog box with the <b>Previous</b> / <b>Next</b> buttons."));
 	detailAction->setEnabled(false);
 
-	tooltipEnabledAction=new KToggleAction(i18n("&Enable Detailed Tooltips"), 0, actionCollection(), "enable_tooltip");
+	tooltipEnabledAction=new TDEToggleAction(i18n("&Enable Detailed Tooltips"), 0, actionCollection(), "enable_tooltip");
 	tooltipEnabledAction->setToolTip(i18n("Disable/Enable the tooltips on the current view"));
 	tooltipEnabledAction->setWhatsThis(i18n("Disables/Enables the tooltips displayed when the cursor hovers a log line."));
 	
 	
 	connect(tooltipEnabledAction, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(slotTooltipEnabled(bool)));
 	
-	newLinesDisplayedAction=new KToggleAction(i18n("&Display New Lines"), 0, actionCollection(), "display_new_line");
+	newLinesDisplayedAction=new TDEToggleAction(i18n("&Display New Lines"), 0, actionCollection(), "display_new_line");
 	newLinesDisplayedAction->setToolTip(i18n("Display or not new lines if the log changes"));
 	newLinesDisplayedAction->setWhatsThis(i18n("Displays or not the new lines if the log changes. This option is useful when you want to see an old log lines and that KSystemLog often refreshes the current view."));
 	
@@ -393,8 +393,8 @@ void KSystemLog::setupActions() {
 void KSystemLog::setupLogActions() {
 	
 	//Define a macro allowing the connection of the signal from log action to the slotLogAction object
-	#if defined(KDE_MAKE_VERSION) && KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
-		#define CONNECTED_SLOT(action) connect(action, TQT_SIGNAL(activated(KAction::ActivationReason, TQt::ButtonState)), slotLogAction, TQT_SLOT(slotLogAction(KAction::ActivationReason, TQt::ButtonState)));
+	#if defined(TDE_MAKE_VERSION) && TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
+		#define CONNECTED_SLOT(action) connect(action, TQT_SIGNAL(activated(TDEAction::ActivationReason, TQt::ButtonState)), slotLogAction, TQT_SLOT(slotLogAction(TDEAction::ActivationReason, TQt::ButtonState)));
 	#else
 		#define CONNECTED_SLOT(action) connect(action, TQT_SIGNAL(activated()), slotLogAction, TQT_SLOT(slotLogAction()));
 	#endif
@@ -406,7 +406,7 @@ void KSystemLog::setupLogActions() {
 	TQString exclusiveGroup="LogActions";
 
 	//System Log Action
-	KToggleAction* systemAction=new KToggleAction(i18n("S&ystem Log"), SYSTEM_MODE_ICON, 0, NULL, NULL, actionCollection(), "system_log" );
+	TDEToggleAction* systemAction=new TDEToggleAction(i18n("S&ystem Log"), SYSTEM_MODE_ICON, 0, NULL, NULL, actionCollection(), "system_log" );
 	systemAction->setToolTip(i18n("Display the system log."));
 	systemAction->setWhatsThis(i18n("Displays the system log in the current tab. This log is generally used by non-specialized processes (like \"sudo\" or \"fsck\" commands)"));
 	systemAction->setExclusiveGroup(exclusiveGroup);
@@ -414,7 +414,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(systemAction)
 	
 	//Kernel Log Action
-	KToggleAction* kernelAction=new KToggleAction(i18n("&Kernel Log"), KERNEL_MODE_ICON, 0, NULL, NULL, actionCollection(), "kernel_log" );
+	TDEToggleAction* kernelAction=new TDEToggleAction(i18n("&Kernel Log"), KERNEL_MODE_ICON, 0, NULL, NULL, actionCollection(), "kernel_log" );
 	kernelAction->setToolTip(i18n("Display the kernel log."));
 	kernelAction->setWhatsThis(i18n("<qt>Displays the kernel log in the current tab. This log is only useful for users who want to know why the Kernel does not detect their hardware or what is the cause of the last <i>kernel panic/oops</i>.</qt>"));
 	kernelAction->setExclusiveGroup(exclusiveGroup);
@@ -422,7 +422,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(kernelAction)
 	
 	//Boot Log Action
-	KToggleAction* bootAction=new KToggleAction(i18n("&Boot Log"), BOOT_MODE_ICON, 0, NULL, NULL, actionCollection(), "boot_log" );
+	TDEToggleAction* bootAction=new TDEToggleAction(i18n("&Boot Log"), BOOT_MODE_ICON, 0, NULL, NULL, actionCollection(), "boot_log" );
 	bootAction->setToolTip(i18n("Display the boot log."));
 	bootAction->setWhatsThis(i18n("<qt>Displays the boot log in the current tab. This log is useful if you want to verify if all startup services have been correctly started.</qt>"));
 	bootAction->setExclusiveGroup(exclusiveGroup);
@@ -430,7 +430,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(bootAction)
 	
 	//Authentication Log Action
-	KToggleAction* authenticationAction=new KToggleAction(i18n("A&uthentication Log"), AUTHENTICATION_MODE_ICON, 0, NULL, NULL, actionCollection(), "authentication_log" );
+	TDEToggleAction* authenticationAction=new TDEToggleAction(i18n("A&uthentication Log"), AUTHENTICATION_MODE_ICON, 0, NULL, NULL, actionCollection(), "authentication_log" );
 	authenticationAction->setToolTip(i18n("Display the authentication log."));
 	authenticationAction->setWhatsThis(i18n("<qt>Displays the authentication log in the current tab. This log displays all log in made by each user of the system, and can help you to know if someone tried to crack your system.</qt>"));
 	authenticationAction->setExclusiveGroup(exclusiveGroup);
@@ -438,7 +438,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(authenticationAction)
 	
 	//Daemon Log Action
-	KToggleAction* daemonAction=new KToggleAction(i18n("&Daemons Log"), DAEMON_MODE_ICON, 0, NULL, NULL, actionCollection(), "daemon_log" );
+	TDEToggleAction* daemonAction=new TDEToggleAction(i18n("&Daemons Log"), DAEMON_MODE_ICON, 0, NULL, NULL, actionCollection(), "daemon_log" );
 	daemonAction->setToolTip(i18n("Display the daemons log."));
 	daemonAction->setWhatsThis(i18n("<qt>Displays the daemons log in the current tab. The daemons are all processes launched in the background of the system. See this log if you want to know what it occurs in the background of your system.</qt>"));
 	daemonAction->setExclusiveGroup(exclusiveGroup);
@@ -446,7 +446,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(daemonAction)
 	
 	//Cron Log Action
-	KToggleAction* cronAction=new KToggleAction(i18n("&Planned Tasks Cron Log"), CRON_MODE_ICON, 0, NULL, NULL, actionCollection(), "cron_log" );
+	TDEToggleAction* cronAction=new TDEToggleAction(i18n("&Planned Tasks Cron Log"), CRON_MODE_ICON, 0, NULL, NULL, actionCollection(), "cron_log" );
 	cronAction->setToolTip(i18n("Display the planned tasks log (or Cron log)."));
 	cronAction->setWhatsThis(i18n("<qt>Displays the planned tasks log in the current tab. Cron process is a program in charged of launching planned tasks on your system, like security checks, or auto-restarting of some services. Use this menu to see the last-launched processes.</qt>"));
 	cronAction->setExclusiveGroup(exclusiveGroup);
@@ -454,7 +454,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(cronAction)
 	
 	//Xorg Log Action
-	KToggleAction* xorgAction=new KToggleAction(i18n("&X.org Log"), XORG_MODE_ICON, 0, NULL, NULL, actionCollection(), "xorg_log" );
+	TDEToggleAction* xorgAction=new TDEToggleAction(i18n("&X.org Log"), XORG_MODE_ICON, 0, NULL, NULL, actionCollection(), "xorg_log" );
 	xorgAction->setToolTip(i18n("Display the X.org log."));
 	xorgAction->setWhatsThis(i18n("<qt>Displays the X.org log in the current tab. X.org is the service which displays on screen your desktop and manage your graphical hardware. See this log if you want to know why you do not have 3D accelerations or why your input device is not recognized.</qt>"));
 	xorgAction->setExclusiveGroup(exclusiveGroup);
@@ -462,7 +462,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(xorgAction)
 	
 	//ACPId Log Action
-	KToggleAction* acpidAction=new KToggleAction(i18n("&ACPI Log"), ACPID_MODE_ICON, 0, NULL, NULL, actionCollection(), "acpid_log" );
+	TDEToggleAction* acpidAction=new TDEToggleAction(i18n("&ACPI Log"), ACPID_MODE_ICON, 0, NULL, NULL, actionCollection(), "acpid_log" );
 	acpidAction->setToolTip(i18n("Display the ACPI log."));
 	acpidAction->setWhatsThis(i18n("<qt>Displays the ACPI log in the current tab. ACPI is used to manage the hardware components of your computer, like notebook batteries, reset buttons...</qt>"));
 	acpidAction->setExclusiveGroup(exclusiveGroup);
@@ -470,7 +470,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(acpidAction)
 
 	//Cups Log Action
-	KToggleAction* cupsAction=new KToggleAction(i18n("&Cups Log"), CUPS_MODE_ICON, 0, NULL, NULL, actionCollection(), "cups_log" );
+	TDEToggleAction* cupsAction=new TDEToggleAction(i18n("&Cups Log"), CUPS_MODE_ICON, 0, NULL, NULL, actionCollection(), "cups_log" );
 	cupsAction->setToolTip(i18n("Display the Cups log."));
 	cupsAction->setWhatsThis(i18n("<qt>Displays the CUPS log in the current tab. CUPS is the program which manage printing on your computer.</qt>"));
 	cupsAction->setExclusiveGroup(exclusiveGroup);
@@ -478,7 +478,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(cupsAction)
 
 	//Cups Access Log Action
-	KToggleAction* cupsAccessAction=new KToggleAction(i18n("&Cups Web Log"), CUPS_ACCESS_MODE_ICON, 0, NULL, NULL, actionCollection(), "cups_access_log" );
+	TDEToggleAction* cupsAccessAction=new TDEToggleAction(i18n("&Cups Web Log"), CUPS_ACCESS_MODE_ICON, 0, NULL, NULL, actionCollection(), "cups_access_log" );
 	cupsAccessAction->setToolTip(i18n("Display the CUPS Web Server Access log."));
 	cupsAccessAction->setWhatsThis(i18n("<qt>Displays the CUPS Web Server Access log in the current tab. CUPS is the program which manage printing on your computer. This log saves all requests performed to the CUPS embedded web server (default: <i>http://localhost:631</i>).</qt>"));
 	cupsAccessAction->setExclusiveGroup(exclusiveGroup);
@@ -487,7 +487,7 @@ void KSystemLog::setupLogActions() {
 	
 
 	//Apache Log Action
-	KToggleAction* apacheAction=new KToggleAction(i18n("&Apache log"), APACHE_MODE_ICON, 0, NULL, NULL, actionCollection(), "apache_log" );
+	TDEToggleAction* apacheAction=new TDEToggleAction(i18n("&Apache log"), APACHE_MODE_ICON, 0, NULL, NULL, actionCollection(), "apache_log" );
 	apacheAction->setToolTip(i18n("Display the Apache log."));
 	apacheAction->setWhatsThis(i18n("<qt>Displays the Apache log in the current tab. Apache is the main used Web server in the world.</qt>"));
 	apacheAction->setExclusiveGroup(exclusiveGroup);
@@ -495,7 +495,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(apacheAction)
 
 	//Apache Access Log Action
-	KToggleAction* apacheAccessAction=new KToggleAction(i18n("&Apache Web log"), APACHE_ACCESS_MODE_ICON, 0, NULL, NULL, actionCollection(), "apache_access_log" );
+	TDEToggleAction* apacheAccessAction=new TDEToggleAction(i18n("&Apache Web log"), APACHE_ACCESS_MODE_ICON, 0, NULL, NULL, actionCollection(), "apache_access_log" );
 	apacheAccessAction->setToolTip(i18n("Display the Apache Access log."));
 	apacheAccessAction->setWhatsThis(i18n("<qt>Displays the Apache Access log in the current tab. CUPS is the program which manage printing on your computer. This log saves all requests performed by the Apache web server.</qt>"));
 	apacheAccessAction->setExclusiveGroup(exclusiveGroup);
@@ -503,7 +503,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(apacheAccessAction)
 	
 	//Mail Log Action
-	KToggleAction* mailAction=new KToggleAction(i18n("&Mail Log"), MAIL_MODE_ICON, 0, NULL, NULL, actionCollection(), "mail_log" );
+	TDEToggleAction* mailAction=new TDEToggleAction(i18n("&Mail Log"), MAIL_MODE_ICON, 0, NULL, NULL, actionCollection(), "mail_log" );
 	mailAction->setToolTip(i18n("Display the Mail log."));
 	mailAction->setWhatsThis(i18n("<qt>Displays the mail log in the current tab. Mail is the most known and used mail server in the Linux world.</qt>"));
 	mailAction->setExclusiveGroup(exclusiveGroup);
@@ -511,7 +511,7 @@ void KSystemLog::setupLogActions() {
 	CONNECTED_SLOT(mailAction)
 	
 	//Samba Log Action
-	KToggleAction* sambaAction=new KToggleAction(i18n("&Samba Log"), SAMBA_MODE_ICON, 0, NULL, NULL, actionCollection(), "samba_log" );
+	TDEToggleAction* sambaAction=new TDEToggleAction(i18n("&Samba Log"), SAMBA_MODE_ICON, 0, NULL, NULL, actionCollection(), "samba_log" );
 	sambaAction->setToolTip(i18n("Display the Samba log."));
 	sambaAction->setWhatsThis(i18n("<qt>Displays the Samba log in the current tab. Samba is the file sharing server which interacts with Microsoft Windows network.</qt>"));
 	sambaAction->setExclusiveGroup(exclusiveGroup);
@@ -678,7 +678,7 @@ LogManager* KSystemLog::newTab() {
 	
 	tabs->insertTab(manager->getView(), SmallIcon(NO_MODE_ICON), i18n("No Log"));
 	
-#if defined(KDE_MAKE_VERSION) && KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
+#if defined(TDE_MAKE_VERSION) && TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
 	if (tabs->count()>1) {
 		tabs->setTabBarHidden(false);
 	}
@@ -776,7 +776,7 @@ void KSystemLog::closeTab() {
 	}
 	*/
 	
-#if defined(KDE_MAKE_VERSION) && KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
+#if defined(TDE_MAKE_VERSION) && TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
 	if (tabs->count()==1) {
 		tabs->setTabBarHidden(true);
 	}
@@ -896,10 +896,10 @@ void KSystemLog::resumeParsing() {
 
 //If no actions are selected, than all are deselected
 void KSystemLog::deactiveLogActions() {
-	TQValueList<KToggleAction*> actions=mapActionLogModes.keys();
+	TQValueList<TDEToggleAction*> actions=mapActionLogModes.keys();
 	
-	KToggleAction* action;
-	TQValueList<KToggleAction*>::iterator it;
+	TDEToggleAction* action;
+	TQValueList<TDEToggleAction*>::iterator it;
 	for (it=actions.begin(); it!=actions.end(); ++it) {
 		action=*it;
 		
@@ -908,17 +908,17 @@ void KSystemLog::deactiveLogActions() {
 	
 }
 
-KToggleAction* KSystemLog::getCorrespondingLogAction(LogMode* mode) {
+TDEToggleAction* KSystemLog::getCorrespondingLogAction(LogMode* mode) {
 	//Special case for no and opening mode
 	//TODO Maybe use a list for "special" log mode, and pre-test the parameter with it
 	if (mode==Globals::noMode || mode==Globals::openingMode)
 		return(NULL);
 
-	TQValueList<KToggleAction*> keys=mapActionLogModes.keys();
+	TQValueList<TDEToggleAction*> keys=mapActionLogModes.keys();
 	
-	TQValueList<KToggleAction*>::iterator it;
+	TQValueList<TDEToggleAction*>::iterator it;
 	
-	KToggleAction* key;
+	TDEToggleAction* key;
 	
 	
 	for (it=keys.begin(); it!=keys.end(); ++it) {
@@ -933,17 +933,17 @@ KToggleAction* KSystemLog::getCorrespondingLogAction(LogMode* mode) {
 }
 
 
-KToggleAction* KSystemLog::getLogAction(const char* name) {
-	return( static_cast<KToggleAction*> (actionCollection()->action(name)) );
+TDEToggleAction* KSystemLog::getLogAction(const char* name) {
+	return( static_cast<TDEToggleAction*> (actionCollection()->action(name)) );
 }
 
-#if defined(KDE_MAKE_VERSION) && KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
-void KSystemLog::logActionClicked(const TQObject* sender, KAction::ActivationReason reason, TQt::ButtonState state) {
+#if defined(TDE_MAKE_VERSION) && TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
+void KSystemLog::logActionClicked(const TQObject* sender, TDEAction::ActivationReason reason, TQt::ButtonState state) {
 #else
 void KSystemLog::logActionClicked(const TQObject* sender) {
 #endif
 	
-	KToggleAction* action=getLogAction(sender->name());
+	TDEToggleAction* action=getLogAction(sender->name());
 	
 	LogMode* mode=mapActionLogModes[action];
 	
@@ -954,7 +954,7 @@ void KSystemLog::logActionClicked(const TQObject* sender) {
 	
 	//TODO Be sure that the + is the right symbol to combine TQt Constants
 	//If the user uses the middle button OR left button + shift OR left button + control : = it opens the log in a new tab
-#if defined(KDE_MAKE_VERSION) && KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
+#if defined(TDE_MAKE_VERSION) && TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
 	if (state==Qt::MidButton || (state==TQt::ControlButton+Qt::LeftButton) || (state==TQt::ShiftButton+Qt::LeftButton))
 		newTab();
 #endif
@@ -1297,7 +1297,7 @@ void KSystemLog::load(LogMode* logMode, LogManager* manager) {
  * config file.  anything you write here will be available
  * later when this app is restored
  */
-void KSystemLog::saveProperties(KConfig* /*config*/) {
+void KSystemLog::saveProperties(TDEConfig* /*config*/) {
 	kdDebug() << "saveProperties method." << endl;
 }
 
@@ -1307,7 +1307,7 @@ void KSystemLog::saveProperties(KConfig* /*config*/) {
  * the app is being restored.  read in here whatever you wrote
  * in 'saveProperties'
  */
-void KSystemLog::readProperties(KConfig* /*config*/) {
+void KSystemLog::readProperties(TDEConfig* /*config*/) {
 	kdDebug() << "readProperties method." << endl;
 }
 
@@ -1317,10 +1317,10 @@ void KSystemLog::dragEnterEvent(TQDragEnterEvent *event) {
 }
 
 void KSystemLog::setupGroupBy() {
-	groupBy=new KActionMenu(i18n("Group By"), SmallIcon(GROUP_BY_ICON), TQT_TQOBJECT(this), "group_by");
+	groupBy=new TDEActionMenu(i18n("Group By"), SmallIcon(GROUP_BY_ICON), TQT_TQOBJECT(this), "group_by");
 	actionCollection()->insert(groupBy);
 
-	KPopupMenu* menu=groupBy->popupMenu();
+	TDEPopupMenu* menu=groupBy->popupMenu();
 	
 	menu->insertItem(SmallIcon(NO_GROUP_BY_ICON), i18n("None"), NO_GROUP_BY);
 	
@@ -1341,7 +1341,7 @@ void KSystemLog::setupGroupBy() {
 }
 
 void KSystemLog::groupByChanged(int group) {
-	KPopupMenu* menu=groupBy->popupMenu();
+	TDEPopupMenu* menu=groupBy->popupMenu();
 
 	for(int i=0; i<(int) menu->count(); ++i) {
 		menu->setItemChecked(menu->idAt(i), false);
@@ -1374,9 +1374,9 @@ void KSystemLog::updateGroupBy() {
 
 	kdDebug() << "Updating group by..." << endl;
 	
-	KPopupMenu* menu=groupBy->popupMenu();
+	TDEPopupMenu* menu=groupBy->popupMenu();
 	
-	//First : removing old KAction
+	//First : removing old TDEAction
 	//The deleting begins at default groupby count + 2 separator (in the menu)
 	int deleting=DEFAULT_GROUP_BY_COUNT+2;
 	int end=menu->count();
