@@ -23,7 +23,7 @@
 #define KSYSTEM_LOG_H
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 
